@@ -11,11 +11,11 @@ Perl::Critic::Bangs - A collection of handy Perl::Critic policies
 
 =head1 VERSION
 
-Version 1.11_03
+Version 1.02
 
 =cut
 
-our $VERSION = '1.11_03';
+our $VERSION = '1.02';
 
 =head1 SYNOPSIS
 
@@ -40,32 +40,26 @@ Tests should have a plan.
 
 =head2 L<Perl::Critic::Policy::Bangs::ProhibitNumberedNames>
 
-Subroutines and variables like C<$user> and C<$user2> are insufficiently
-distinguished.
+Variables like C<$user> and C<$user2> are insufficiently distinguished.
 
 =head2 L<Perl::Critic::Policy::Bangs::ProhibitRefProtoOrProto>
 
 Determining the class in a constructor by using C<ref($proto) || $proto> is usually
 a cut-n-paste that is incorrect.
 
-=head2 L<Perl::Critic::Policy::Bangs::ProhibitUselessTopic>
-
-Explicitly matching or substituting against C<$_> is clutter.
-
 =head2 L<Perl::Critic::Policy::Bangs::ProhibitUselessRegexModifiers>
 
 Adding modifiers to a regular expression made up entirely of a
-variable created with C<qr()> is usually not doing what you expect.
+variable created with qr() is usually not doing what you expect.
 
 =head2 L<Perl::Critic::Policy::Bangs::ProhibitVagueNames>
 
-Vague variables and subroutines like C<$data> or C<$info> are not
-descriptive enough.
+Vague variables like C<$data> or C<$info> are not descriptive enough.
 
-=head1 WHY IS IT CALLED Perl::Critic::Bangs?
+=head1 WHY BANGS?
 
 I didn't want to call it "Perl::Critic::Lester" or "Perl::Critic::Petdance"
-since that would make it sound like they were only my rules.  Other people
+that would make it sound like they were only my rules.  Other people
 will likely include their own set of rules, too.
 
 So I started thinking of names of famous critics.  Ebert, Siskel,
@@ -112,30 +106,35 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Perl-Critic-Bangs>
 
 L<http://search.cpan.org/dist/Perl-Critic-Bangs>
 
-=item * Source code repository
+=item * Subversion repository
 
-L<http://github.com/petdance/perl-critic-bangs>
+L<http://perl-critic-bangs.googlecode.com/svn/>
 
 =back
 
 =head1 ACKNOWLEDGMENTS
 
 Thanks to
-William Braswell,
-Oliver Trosien,
-Fred Moyer,
-Andy Moore,
-Oystein Torget,
-Mike O'Regan,
-Elliot Shank
-and the rest of the Perl::Critic team for ongoing support.
+
+=over 4
+
+=item * Andy Moore for helping me get this off the ground.
+
+=item * Oystein Torget for bug reports and patches.
+
+=back
 
 =head1 COPYRIGHT
 
-Copyright 2006-2017 Andy Lester.
+Copyright (C) 2006-2009 Andy Lester
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the Artistic License 2.0.
+This library is free software; you can redistribute it and/or modify
+it under the terms of either the GNU Public License v3, or the Artistic
+License 2.0.
+
+    * http://www.gnu.org/copyleft/gpl.html
+
+    * http://www.opensource.org/licenses/artistic-license-2.0.php
 
 =cut
 
