@@ -5,7 +5,7 @@ use warnings;
 use Perl::Critic::Utils;
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.11_03';
+our $VERSION = '1.02';
 
 #----------------------------------------------------------------------------
 
@@ -20,9 +20,9 @@ sub supported_parameters {
     );
 }
 
-sub default_severity     { return $SEVERITY_LOW                             }
-sub default_themes       { return qw( bangs maintenance )                   }
-sub applies_to           { return qw( PPI::Token::Comment PPI::Token::Pod ) }
+sub default_severity     { return $SEVERITY_LOW           }
+sub default_themes       { return qw( bangs maintenance ) }
+sub applies_to           { return 'PPI::Token::Comment'   }
 
 
 #---------------------------------------------------------------------------
@@ -43,6 +43,11 @@ sub violates {
 1;
 
 __END__
+
+#---------------------------------------------------------------------------
+
+=pod
+
 =for stopwords FIXME
 
 =head1 NAME
@@ -79,10 +84,15 @@ Based on App::Fluff by Andy Lester, "<andy at petdance.com>"
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2013 Andy Lester <andy@petdance.com> and Andrew
+Copyright (c) 2006-2009 Andy Lester <andy@petdance.com> and Andrew
 Moore <amoore@mooresystems.com>.
 
 This library is free software; you can redistribute it and/or modify
-it under the terms of the Artistic License 2.0.
+it under the terms of either the GNU Public License v3, or the Artistic
+License 2.0.
+
+    * http://www.gnu.org/copyleft/gpl.html
+
+    * http://www.opensource.org/licenses/artistic-license-2.0.php
 
 =cut
