@@ -5,7 +5,7 @@ use warnings;
 use Perl::Critic::Utils;
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.11_03';
+our $VERSION = '1.02';
 
 sub supported_parameters { return ()                     }
 sub default_severity     { return $SEVERITY_HIGH         }
@@ -22,7 +22,7 @@ sub violates {
     return if is_subroutine_name($elem);
 
     my $suspectproto = $elem->snext_sibling();
-    if ( $suspectproto && $suspectproto->isa( 'PPI::Token::Symbol' ) ) {
+    if ( $suspectproto->isa( 'PPI::Token::Symbol' ) ) {
         # $suspectproto is the thing I'm calling ref on. Let's see if there's a || after that.
         if ( $suspectproto->snext_sibling()
                 && $suspectproto->snext_sibling->isa( 'PPI::Token::Operator' )
@@ -31,8 +31,8 @@ sub violates {
             # this is where I test to see if the thing after the || is the same as the thing before the ref
             if ( $or->snext_sibling() eq $suspectproto->content() ) {
                 # here it looks like we have ref $proto || $proto
-                my $desc = q{"ref $proto || $proto" construct found}; ## no critic (RequireInterpolationOfMetachars)
-                my $expl = q{Probably cut-and-pasted example code};
+                my $desc = q("ref $proto || $proto" construct found); ## no critic
+                my $expl = q(Probably cut-and-pasted example code);
                 return $self->violation( $desc, $expl, $elem );
             }
         }
@@ -44,9 +44,14 @@ sub violates {
 1;
 
 __END__
+
+#---------------------------------------------------------------------------
+
+=pod
+
 =head1 NAME
 
-Perl::Critic::Policy::Bangs::ProhibitRefProtoOrProto - Create a clone() method if you need copies of objects.
+Perl::Critic::Policy::Bangs::ProhibitRefProtoOrProto - Create a C<clone()> method if you need copies of objects.
 
 =head1 AFFILIATION
 
@@ -105,9 +110,14 @@ and work done by Andrew Moore <amoore@mooresystems.com>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006-2013 Andy Lester
+Copyright (C) 2006-2009 Andy Lester
 
-This library is free software; you can redistribute it and/or modify it
-under the terms of the Artistic License 2.0.
+This library is free software; you can redistribute it and/or modify
+it under the terms of either the GNU Public License v3, or the Artistic
+License 2.0.
+
+    * http://www.gnu.org/copyleft/gpl.html
+
+    * http://www.opensource.org/licenses/artistic-license-2.0.php
 
 =cut
