@@ -5,9 +5,10 @@ use warnings;
 use Readonly;
 
 use Perl::Critic::Utils qw{ :severities :classification :ppi };
+use Perl::Critic::Utils::PPIRegexp qw{ &get_modifiers &get_match_string };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.11_03';
+our $VERSION = '1.02';
 
 Readonly::Scalar my $DESC => q{Prohibits adding "m" modifier to compiled regular expressions where it does nothing};
 Readonly::Scalar my $EXPL => <<'EOF';
@@ -30,13 +31,13 @@ sub violates {
     my ( $self, $elem, undef ) = @_;
 
 
-    # We throw a violation if all these conditions are true:
+    # we throw a violation if all these conditions are true:
     # 1) there's an 'm' modifier
     # 2) the *only* thing in the regex is a compiled regex from a previous qr().
     # 3) the modifiers are not the same in both places
-    my %mods = $elem->get_modifiers();
+    my %mods = get_modifiers($elem);
     if ( $mods{'m'} || $mods{'s'} ) {
-        my $match = $elem->get_match_string();
+        my $match = get_match_string( $elem );
         if ( $match =~ /^\$\w+$/smx ) {  # It looks like a single variable in there
             if ( my $qr = _previously_assigned_quote_like_operator( $elem, $match ) ) {
                 # don't violate if both regexes are modified in the same way
@@ -69,7 +70,7 @@ sub _find_previous_quote_like_regexp {
 
     my $qlop = $elem;
     while ( ! $qlop->isa( 'PPI::Token::QuoteLike::Regexp' ) ) {
-        # We use previous_token instead of sprevious_sibling to get into previous statements.
+        # we use previous_token instead of sprevious_sibling to get into previous statements.
         $qlop = $qlop->previous_token() or return;
     }
     return $qlop;
@@ -78,13 +79,14 @@ sub _find_previous_quote_like_regexp {
 sub _sorted_modifiers {
     my $elem = shift;
 
-    my %mods = $elem->get_modifiers();
+    my %mods = get_modifiers( $elem );
     return join( '', sort keys %mods );
 }
 
 1;
 
-__END__
+=pod
+
 =head1 NAME
 
 Perl::Critic::Policy::Bangs::ProhibitUselessRegexModifiers - Adding modifiers to a regular expression made up entirely of a variable created with qr() is usually not doing what you expect.
@@ -100,15 +102,13 @@ incorrectly applied. This was fixed in 5.10, but no warnings were
 emitted to warn the user that they were probably not getting the
 effects they are looking for.
 
-Correct:
+correct:
+  my $regex = qr(abc)m;
+  if ( $string =~ /$regex/ ) {};
 
-    my $regex = qr(abc)m;
-    if ( $string =~ /$regex/ ) {};
-
-Not what you want:
-
-    my $regex = qr(abc);
-    if ( $string =~ /$regex/m ) {}; ## this triggers a violation of this policy.
+Not what you want::
+  my $regex = qr(abc);
+  if ( $string =~ /$regex/m ) {}; ## this triggers a violation of this policy.
 
 See the thread that starts at:
 L<http://www.nntp.perl.org/group/perl.perl5.porters/2007/12/msg131709.html>
@@ -133,10 +133,15 @@ Thanks to Andy Lester, "<andy at petdance.com>" for pointing out this common pro
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2013 Andy Lester <andy@petdance.com> and Andrew
+Copyright (c) 2007-2009 Andy Lester <andy@petdance.com> and Andrew
 Moore <amoore@mooresystems.com>
 
-This library is free software; you can redistribute it and/or modify it
-under the terms of the Artistic License 2.0.
+This library is free software; you can redistribute it and/or modify
+it under the terms of either the GNU Public License v3, or the Artistic
+License 2.0.
+
+    * http://www.gnu.org/copyleft/gpl.html
+
+    * http://www.opensource.org/licenses/artistic-license-2.0.php
 
 =cut
